/*
#    Texplore:
#       A simple Type Explorer for GObject based libraries.
#    Copyright (C) June, 2005 Muthiah Annamalai
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "menu.h"
#include "about.h"
#include "../config.h"

static void
texplore_about(GtkAction *ae)
{
  static GtkWidget *about=NULL;
  GtkAboutDialog *abt=NULL;
  static GdkPixbuf *logo=NULL;
  static const gchar *authors[]={"Muthiah Annamalai",NULL};
  static gchar *comments = "Type Explorer\n A simple GTK program to explore\n GObject Types, using a introspection\n capability present in the GObject/GLib\n Type System and Libraries";
  static char *website = "http://octave-gtk.sf.net/Texplore";
  
  if(!logo)
    logo=gdk_pixbuf_new_from_file(TEXPLORE_DOC_DIR "/gnome-emacs.png",NULL);

  if(!about)
    {
      about=create_about_dialog("Type Explorer","0.1",
				"(C) June  2005 Muthiah Annamalai GNU GPL 2.0",
				comments,authors,NULL,NULL,website,logo);
      
      g_signal_connect(G_OBJECT(about),"response",G_CALLBACK(gtk_widget_hide),NULL);
    }
  
  gtk_widget_show_all(about);
  return;
}

static GtkActionEntry aes[] =
  {
    {
      "File",GTK_STOCK_FILE,"_File",
      "<alt>F","File"
    },
    {
      "Close",GTK_STOCK_CLOSE,"_Close",
      "<control>w","Close program",G_CALLBACK(gtk_main_quit)
    },
    {
      "Quit",GTK_STOCK_QUIT,"_Quit",
      "<control>q","Exit or Quit program",G_CALLBACK(gtk_main_quit)
    },
    {
      "About",GTK_STOCK_ABOUT,"_About",
      "A","About program",G_CALLBACK(texplore_about)
    },
    {
      "Help",GTK_STOCK_HELP,"_Help",
      NULL,"Help for you",
    },
    
  };

static char *menu_str=
"<ui>"
"  <menubar name='MenuBar'>"
"    <menu action='File'>"
"      <menuitem action='Close'/>"
"      <separator/>"
"      <menuitem action='Quit'/>"
"    </menu>"
"    <menu action='Help'>"
"	<menuitem action='About'/>"
"    </menu>"
"  </menubar>"
"</ui>";

GtkWidget * create_menu(GtkWidget *window)
{
  GtkWidget *w;
  GtkActionGroup *ag;
  GtkUIManager *man;

  g_assert(GTK_IS_WINDOW(window));
  g_return_val_if_fail(GTK_IS_WINDOW(window),NULL);

  ag=gtk_action_group_new("WindowActionGroup");
  gtk_action_group_add_actions(ag,aes,sizeof(aes)/sizeof(GtkActionEntry),NULL);

  man=gtk_ui_manager_new();
  gtk_ui_manager_insert_action_group(man,ag,0);
  gtk_window_add_accel_group(GTK_WINDOW(window),
			     gtk_ui_manager_get_accel_group(man));

  gtk_ui_manager_add_ui_from_string(man,menu_str,-1,NULL);

  gtk_ui_manager_new_merge_id(man);
  w=gtk_ui_manager_get_widget(man,"/MenuBar");
  g_object_set_data(G_OBJECT(w),"ui-manager",man);

  return w;
}
