/*
#    Texplore:
#       A simple Type Explorer for GObject based libraries.
#    Copyright (C) June, 2005 Muthiah Annamalai
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "table.h"
#include "types.h"


static gboolean
detail_type_cb (GtkTreeSelection  *selection,
		GtkTreeModel      *model,
		GtkTreePath       *path,
		gboolean           path_currently_selected,
		gpointer           data)
{
  GtkTreeView *type_view = GTK_TREE_VIEW(data);
  GtkTreeIter  iter;
  GtkTreeView *tv=NULL;
  const gchar *text;
  gint id;
  GValue *c=NULL;

  c=g_new0(GValue,2);
  tv=gtk_tree_selection_get_tree_view(selection);

  gtk_tree_model_get_iter ( model, &iter, path);

  gtk_tree_model_get_value( model, &iter, 0, &c[0]);
  gtk_tree_model_get_value( model, &iter, 1, &c[1]);

  text=g_value_get_string(&c[0]);
  id=g_value_get_int(&c[1]);

  /* g_message(" New Text=%s id=%d",text,id); */
  
  
  gtk_widget_queue_draw(GTK_WIDGET(tv));
  g_free(c);
   
  /* Open a New Window & start show details for this type. */
  type_view_update_type(GTK_WIDGET(type_view),id);
  
  return TRUE;
}

GtkWidget * create_table(GtkWidget *type_view)
{
  GtkListStore *ls;
  GtkTreeIter ti;
  GtkWidget *tv,*scrwin;
  GtkTreeViewColumn *tvc;
  GtkCellRenderer *cell;
  GtkTreeSelection *ts;

  TexploreTypeData *td=(TexploreTypeData *)texplore_init_types();

  ls=gtk_list_store_new(2,G_TYPE_STRING,G_TYPE_INT);

  while(td!=NULL && td->TypeID>= 0 && td->TypeString!=NULL)
    {
      gtk_list_store_append(ls,&ti);
      gtk_list_store_set(ls,&ti,
			 0,td->TypeString,
			 1,td->TypeID,
			 -1);
      td++;
    }

  tv=gtk_tree_view_new_with_model(GTK_TREE_MODEL(ls));

  cell=gtk_cell_renderer_text_new();
  tvc=gtk_tree_view_column_new_with_attributes("Type",cell,"text",0,NULL);

  gtk_tree_view_append_column(GTK_TREE_VIEW(tv),tvc);
  
  ts=gtk_tree_view_get_selection(GTK_TREE_VIEW(tv));
  gtk_tree_selection_set_mode(ts,GTK_SELECTION_SINGLE);
  gtk_tree_selection_set_select_function(ts, 
					 (GtkTreeSelectionFunc)detail_type_cb,
					 (gpointer)type_view,NULL);

  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tv), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (tv),TRUE);
  gtk_tree_view_set_search_column (GTK_TREE_VIEW (tv), 0);



  scrwin=gtk_scrolled_window_new(NULL,NULL); 
  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrwin),
				 GTK_POLICY_AUTOMATIC,
				 GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrwin),
					tv);

  return scrwin;
}
